bayespy.inference.vmp.nodes.expfamily.ExponentialFamilyDistribution.random
==========================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.expfamily

.. automethod:: ExponentialFamilyDistribution.random